#
# spec file for package audacity
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with vst3

Name:           audacity
Version:        3.7.4
Release:        2.0.4.1.sr20250601
Summary:        A Multi Track Digital Audio Editor
License:        CC-BY-3.0 AND GPL-2.0-or-later AND GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://audacityteam.org/
Source:         https://github.com/audacity/audacity/archive/Audacity-%{version}.tar.gz
Source1:        audacity-license-nyquist
Source2:        audacity-rpmlintrc
%if %{with vst3}
#Source3:        vst3sdk-3.7.12_build_20.tar.xz
%endif
# PATCH-FIX-OPENSUSE audacity-no_buildstamp.patch davejplater@gmail.com -- Remove the buildstamp.
Patch0:         audacity-no_buildstamp.patch
# PATCH-FIX-UPSTREAM audacity-no_return_in_nonvoid.patch - Fix false positive errors Two new gcc10 ones ignoring assert
Patch1:         audacity-no_return_in_nonvoid.patch
# PATCH-FIX-OPENSUSE vst-system-path.patch - search fo vsts in /usr/lib64 in x86_64 and ARM system
Patch2:         Use-full-function-prototypes-in-libnyquist.patch
Patch3:         lib64-plugins-default-path.patch
BuildRequires:  cmake >= 3.16
BuildRequires:  desktop-file-utils
%if 0%{?suse_version} < 1600
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif
#!BuildIgnore:  gstreamer-0_10-plugins-base
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmp3lame-devel
BuildRequires:  portmidi-devel
BuildRequires:  wxWidgets-3_2-nostl-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(flac) >= 1.3.1
BuildRequires:  pkgconfig(flac++)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(id3tag)
BuildRequires:  pkgconfig(id3tag)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec) >= 51.53
BuildRequires:  pkgconfig(libavformat) >= 52.12
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(lilv-0) >= 0.24.6
BuildRequires:  pkgconfig(lv2) >= 1.16.0
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(serd-0) >= 0.30.2
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(sord-0) >= 0.16.4
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(sratom-0) >= 0.6.4
BuildRequires:  pkgconfig(suil-0)  >= 0.10.6
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vamp-hostsdk)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xkbcommon-x11)
# WARNING lilv-0 >= 0.24.6;lv2 >= 1.16.0;serd-0 >= 0.30.2;sord-0 >= 0.16.4;sratom-0 >= 0.6.4;suil-0 >= 0.10.6
# check these versions after every update otherwise audacity builds libsuil itself.

# This would require to patch our portaudio package with "PortMixer"... an extra API that never got integrated in PortAudio.
#BuildRequires:  portaudio-devel
Recommends:     %{name}-lang
# Nothing provides libavutil without a suffix
Requires:       ffmpeg
Requires:       libmp3lame0
Provides:       %{name}-plugins = %{version}
Obsoletes:      %{name}-plugins <= 2.4.2
# pipewire-libjack-0_3 replaces jack and when audacity loads it
# causes a sigsev See https://bugzilla.suse.com/show_bug.cgi?id=1191585
#Conflicts:      pipewire-libjack-0_3
#Doesn't build for 32 bit anymore
#error All sample block data is little endian...big endian not yet supported
ExcludeArch:    i586 s390x

%description
Audacity is a program that manipulates digital audio wave forms.
In addition to multitrack recording capabilities with effects, it
imports and exports many sound file formats, including WAV, AIFF,
AU, IRCAM, MP, and Ogg Vorbis. Wave data larger than the available
physical memory size can be edited.

%lang_package

%prep
%setup -q -n %{name}-Audacity-%{version}
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1

%ifarch x86_64 aarch64
%patch -P 3 -p1
%endif

cp -f %{SOURCE1} LICENSE_NYQUIST.txt
# Make sure we use the system versions.
rm -rf lib-src/{expat,libvamp,libsoxr,ffmpeg,lame}/

#Included in src/AboutDialog.cpp but not supplied
touch include/RevisionIdent.h

%if %{with vst3}
tar xf %{SOURCE3} --strip-components=1 --one-top-level=vst3sdk
%endif

%build
%if 0%{?suse_version} < 1600
export CC=gcc-12
export CXX=g++-12
%endif
if ! test -e %{_libdir}/pkgconfig/lame.pc
then
export PKG_CONFIG_PATH="`echo $PWD`:%{_libdir}/pkgconfig"
fi
export CFLAGS="%{optflags} -fno-strict-aliasing -ggdb $(wx-config --cflags)"

%cmake  \
       -DAUDACITY_REV_TIME=$(date -u -d "@${SOURCE_DATE_EPOCH}" "+%Y-%m-%dT%H:%M:%SZ") \
       -DAUDACITY_REV_LONG=%{version} \
       -DAUDACITY_BUILD_LEVEL=2 \
       -DCMAKE_MODULE_LINKER_FLAGS:STRING="$(wx-config --libs)" \
       -DCMAKE_SHARED_LINKER_FLAGS:STRING="$(wx-config --libs)" \
       -Daudacity_conan_enabled=Off \
       -Daudacity_has_networking:BOOL=Off \
       -Daudacity_lib_preference:STRING=system \
       -Duse_lame:STRING=system \
       -Daudacity_use_ffmpeg:STRING=loaded \
%if %{without vst3}
       -Daudacity_has_vst3=off \
%endif
       -DVST3_DEFAULT_INSTALL_PATH=%{_libdir}/vst3/

%cmake_build

%install
%cmake_install

# E-mail wrote to feedback@audacityteam.org.
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/mimetypes/
mv -f %{buildroot}%{_datadir}/pixmaps/gnome-mime-application-x-audacity-project.xpm \
  %{buildroot}%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-audacity-project.xpm
rm -rf %{buildroot}%{_datadir}/pixmaps/
rm -rf %{buildroot}%{_datadir}/doc

%find_lang %{name}

%post
ldconfig %{_libdir}/%{name}
%end

%postun
ldconfig %{_libdir}/%{name}
%end

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE.txt LICENSE_NYQUIST.txt
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_libdir}/%{name}/modules/mod-script-pipe.so
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Tue Jun 17 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- Add Use-full-function-prototypes-in-libnyquist.patch fixing build
  with gcc-15
* Tue Jun 10 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.7.4
  This is a patch release. It contains the following changes:
  * #6890 Fixed a crash when closing a large unsaved project
  * #8709 Fixed a crash when using real-time effects that activate
    delay compensation
  * #8494 Fixed issue where Studio Fade Out creates a new clip when
    applied at the end of a clip
  * #8442 Fixed incorrect waveform rendering on clipped audio
  * #8559 Fixed unintended deletion of a clip when joining two clips
    with pitch adjustment
  * #3003 Effect preview now works when the track is muted
  * #8666 Fixed possible incorrect calculations in the Hamming window
    derivative (Thanks, witwald!)
  * #8577 Fixed compilation issues on legacy macOS (Thanks, barracuda156!)
* Thu Mar 13 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.7.3
  This is a hotfix release. It fixes the following bugs:
  * #8426 Incorrect results when applying effects to multiple clips
  * #8425 Truncate Silence fails to work properly when there is more
    than one silent part
* Wed Mar 12 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.7.2
- Refresh audacity-no_buildstamp.patch
  This is a patch release. It contains the following changes:
  * #8290 Fixed a crash when applying some effects across multiple
    tracks if one track is empty.
  * #8157, #8155 Fixed some crashes emanating from the Mixer window.
  * #7672 Returned the "Residue" option in noise reduction.
    (Thanks, Christopher Rooney!)
  * #7809 Modules are now allowed to stick around when patch releases
    like this one are published. This means you likely won't need to
    update the OpenVINO again during 3.7.x.
  * #7076 When adding a realtime effect to a track, the effect
    settings are now opened immediately.
  * #7819 Added an infobox when saving a project in a new version
    breaks compatibility with an old one.
  * #7740 Added a preference to turn off automatic tempo detection.
  * #4169 When duplicating tracks, the duplicated tracks now have
    independent realtime effect instances.
  * #7700 Fixed range-selection beyond the edge of a clip being
    destructive.
  * #8013, #8008, #8004, #8009, #8003, #8005, #8071 Improved
    stability of cloud saving.
  * #7410 Fixed pasting content from a clip at the beginning of itself
    being offset in time.
  * #4231 macOS: Fixed AUSoundIsolation.
  * #6342 Fixed audacity continuing to scroll after letting go of
    the scrollbar.
  * #8110 Fixed black stripes appearing when zooming in while in
    the envelope or multi-tool.
  * #8043 Added a new "get effects" button next to the Upload Audio button.
  * #8211 Added UUID instance support. See this page for further
    info: https://forum.audacityteam.org/t/introducing-a-uuid-system-in-audacity-here-s-what-you-need-to-know/128561
  * #7154 Fixed label texts using the wrong color in dark themes.
    (Thanks, GovindaMadhava!)
  * #8261 Fixed tracks being incorrectly drawn on high zoom levels
    using high precision trackpads.
  * #7902 Linux: Fixed FFmpeg loading in the Ubuntu 22.04 AppImage.
* Fri Dec 13 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.7.1
  This is a patch release. It fixes the following bugs:
  * #7797 Effects can be applied to time-stretched clips.
  * #7620 Moving or renaming the installation directory no longer
    re-enables disabled modules.
  * #7652 Opening the "Adjust Playback Speed" dialog doesn't crash
    Audacity anymore.
* Fri Nov  1 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Disable VST3 support due CVE-2024-50602 and misssing VST3 plugins UI
- Fixes boo#1232608
- Update to 3.7.0
  * #6233, #7397, #6900 Improved Linux compatibility.
  * #6702 Improved contrast in the light theme.
  * #7008 MP3 exports: Renamed "Insane" to "Excessive".
  * #7570, #7452 Improved non-standard character handling for cloud
    saving.
  * #7486 Renamed "Split cut/delete" to "Cut/delete and leave gap".
  * #7293 Pasting clips no longer moves clips on other tracks if
    "editing clips can move other clips" is enabled.
  * #7312, #7382 Fixed database compacting not working properly sometimes.
  * #6851 Improved startup speed on systems with many audio devices.
  * #7186 Multi view: Fixed the hitbox of the x being misaligned with
    the visuals. (Thanks, Kurtsley)
  * #7468 macOS: Fixed VST presets path.
  * #7571 Adding, removing, replacing and reordering of effects now
    is undoable.
  * #7573 Closing a project upon turning a realtime effect stack on
    and off doesn't crash Audacity anymore.
  * #7610 Canceling a stereo track mid-operation no longer crashes Audacity.
  * #7385 Importing Opus files using libopus no longer shifts the audio data.
* Sat Sep 21 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Remove old Leap (15.3) workarounds
- Update audacity-no_buildstamp.patch and fix cmake params in spec file
- Update to 3.6.4
  * #7310 Fixed another crash when exiting Audacity. (Thanks, Joe Souza!)
  * #7312 Fixed projects not being compacted on close.
* Mon Sep  9 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update vst3sdk to 3.7.12_build_20
- Update to 3.6.3
  * #7266 Fixed a crash when exiting Audacity. (Thanks, Joe Souza!)
- Updated 3.6.2 release notes:
  * This is a patch release. It adds a "Legacy" effects section
    containing the old Limiter, Compressor and Classic Filters.
  * #6995 Fixed a hang after undoing.
  * #6912 Fixed the zero line going missing.
  * #6927 Fixed envelope appearance for clips offset from 0.
  * #6955 Fixed Audacity turning white on some systems.
  * #6857 Fixed the pitch indicator disappearing on Linux when
    hitting double digits.
  * #6941 Fixed cutting not putting clips into the clipboard.
  * #6926 Fixed pasting sometimes resetting the clip name.
  * #6751 Fixed the track header UI breaking when resizing channels
    in a stereo track.
  * #6847, #6846 Fixed LV2 plugin detection on macOS and Windows.
  * #3679 Fixed Labeled Audio operations.
  * #6924, #6989 Fixed Cloud projects sometimes not opening.
  * #7060 Fixed a bug regarding stereo-to-mono splitting.
  * #7055 Fixed a bug causing tracks with master effects sometimes
    only exporting silence.
  * #7025, #7133 Fixed multi-channel OGG and Wavpack import.
  * #7018 Fixed a crash after recording long sessions.
  * #7126 Fixed a crash when failing to load a cloud project.
  * #7093 Fixed Audacity maxing out the CPU when minimized.
  * #7124 Fixed the "editing clips can move other clips" preference
    desynchronizing multiple tracks.
  * Other changes:
  * #6736 The time track range now is a single dialog.
  * #6929 Reverted the behavior of selection change when importing
    a clip to the previous behavior.
* Sat Jul 27 2024 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update to 3.6.2
  * #6955 Fix out of bound access in waveform cache
  * #6857 fix: pitch-shift value not showing on Linux
  * #6883 Fix for labeled audio operations don't work in certain cases
  * Fix for TCP UI Breaks when dragging waveform splitter
  * Undo stack is cleared before project is compacted
  * Call SetBypass at the right time
  * Clear clipboard also before cutting
  * Prepare a set of tracks to apply labeled audio operations depending
  * Extend Join Region by one sample, to ensure that Split-Join operation
  * Envelope display fix: pass absolute time value when querying envelope
* Mon Jul 22 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.6.1
  This is a hotfix release. It fixes the following bugs:
  * #6889 Fixed a crash when exporting multichannel audio.
  * #6882 Fixed a crash when pasting mono clips into stereo tracks.
  * #4763 (Accessibility) Made more values available when using the
    plain UI of plugins. (Thanks, David Bailes!)
  * #6855 Prevented incompatible versions from opening projects
    created in 3.6.x.
  * #6892 Fixed the dark theme sometimes having white corners in buttons.
* Wed Jul 17 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.6.0
- Remove mod-script-pipe-disable-rpath.patch - no need anymore.
  Major changes
  * Master effects
  - Audacity now features master effects. Master effects are effects
    which apply to the entire project at once. More information can
    be found at Using master effects & realtime effects.
  * New compressor and limiter
  - A new compressor and limiter has been added, replacing the
    previous versions. A gain reduction history has been added to
    these effects when they're used as a realtime effect.
  - Factory Presets suitable for a wide range of use cases for these
    effects have been provided by Vladislav Isaev and Marek Iwaszkiewicz,
    available via the Presets & Settings button.
  * New themes
  - Audacity now features new and improved dark and light themes.
    You can switch between themes via Preferences -> Interface.
  - The theme previously used still is around as the Classic theme,
    and themes even older than that can be optionally installed as
    custom themes[1] from here[2].
    Updated instructions on creating custom themes can be found here[3].
    [1]https://support.audacityteam.org/basics/customizing-audacity/using-themes#installing-custom-themes
    [2]https://github.com/LWinterberg/classicTheme
    [3]https://audacity.gitbook.io/dev/scripting/creating-custom-themes
  * Increased performance
  - Audacity is now quite a bit snappier than before, especially when
    working on larger projects and on larger screens.
  Other changes
  * Added FFmpeg 7 support.
  * You now can paste audio files into Audacity using Ctrl+V.
  * Alternative waveform colors are now themeable by custom themes.
  * Removed the track name overlay preference and the "blend themes"
    preference.
  * Scripting: Added GetInfo: Type=Selection. (Thanks, Jonatã Bolzan Loss!)
  * Added an Extras > Export > Export Selected Audio option.
  * Import Raw: Added support for offsets larger than 2 GB.
  * Redesigned the "what's new" dialog.
  * Added an option to the View menu to show/hide RMS in waveforms.
  * OpenVINO AI effects can now be downloaded from audacityteam.org/download/openvino/
  Bugfixes
  * #6340 When recording to a new track, the track is now scrolled
    back into view again.
  * #3825 The macro manager no longer shows parameterless actions
    as editable. (Thanks, Davi Nonnenmacher!)
  * #6138 Pressing Esc in some preference dialogs no longer saves them.
  * #4504 Fixed stray orange lines in the high contrast theme.
  * #5626 Fixed the quality slider for Ogg export on Linux. (Thanks, Devpriya Nalin!)
  * #6875 Fixed a bug which could open a project with the wrong sample rate.
  * Various compiler warning fixes and OpenBSD build fixes. (Thanks, Brad Smith!)
* Tue Apr 30 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update VST3SDK to latest 3.7.11_build10
- Remove vst3sdk-fix-include-cstdint-for-gcc13.patch and
    vst3sdk-fix-limits-include-moduleinfoparser.patch
- Update to 3.5.1
  This is a hotfix release. It fixes the following bugs:
  * #6322 Fixed a crash on launch on macOS 11 and older.
  * #6324 Fixed the update notification looking for alpha versions
    instead of release versions.
  * #6321 Fixed a freeze when using macros on multiple files.
- Version 3.5.0 changes:
  Major changes
  * Cloud project saving
  * We've introduced a new cloud-saving feature that allows you to
    save your Audacity projects to audio.com. This allows you to work
    from any device, share & collaborate with others and restore
    previous versions if something went wrong.
  * Automatic tempo detection
  * Audacity can now automatically detect the tempo of imported loops,
    and adjust them to be in tempo.
  * Tempo detection is done via both audio analysis and metadata checking.
    If you want to prepare your loop for automatic tempo detection
    without relying on audio analysis, both acidizer tempo tags or
    simply writing "123 bpm" anywhere into the filename work.
  * Automatic tempo detection can be turned off via Preferences -> Import/Export.
  * Pitch shifting
  * You now can non-destructively change the pitch of a clip by
    holding Alt and pressing the Up and Down arrow keys. Alternatively,
    you can click on the overflow menu (...) and select "Pitch and speed...".
    When changing the pitch this way, an arrow in the UI indicates
    how much you've shifted it.
  Other changes
  Additions
  * Added an option to skip plugin scanning to Preferences -> Effects.
  * Added an overflow menu, as well as speed and pitch indicators to clips.
  * Added subtitle formats for labels. Export to WebVTT and SubRip and
    import of SubRip files is now supported. (Thanks, Pokechu22 and
    Larry Bordowitz!)
  Changes
  * Reworked the plugin manager.
  * Improved accessibility. (Thanks, David Bailes!)
  * When zooming in vertically (Ctrl+scroll on the vertical
    scale), the zeroline now remains centered. Moving the vertical
    zoom off-center still is possible via Shift+scroll on the vertical scale.
  * Changed the look of the selection adjust cursors (previously pointing
    fingers on Windows and macOS, now look like >| everywhere).
  * Changed the timeline options button from a green triangle to
    a settings gear. From it, you can switch between Beats & Measures
    or hh:mm:ss timeline rulers, set various preferences regarding to looping,
    as well as playhead behaviors: "Scroll view to playhead"
    (previously: "Update display while playing") and "Continuous scrolling"
    (previously: Pinned Play Head).
  * Improved BSD support. (Thanks, Brad Smith!)
  * macOS: Changed the Audacity.app icon on macOS to fit new design guidelines.
  * Reordered some menus.
  * Moved OK/Cancel buttons of effects to the bottom.
  Removals
  There have been a number of removals of niche features to simplify the app.
  This should make the app a bit less overwhelming to use, and
  also will speed up future development as fewer things need to be considered.
  * Removed the read-only mouse preferences page.
  * Removed Printing options.
  * Removed Screenshot tool. To make a screenshot,
    use Win+Shift+S (Windows) or Cmd+Shift+4 (Mac) instead.
  * Removed Karaoke view.
  * Removed the "solo=none" preference.
  * Removed timeline tooltips preference.
  * Removed "dragging selection edges" preference.
  * Removed some warning dialogs and associated preferences.
  * Removed "scrolling left of zero" preference.
  * Replaced "Advanced Vertical Zooming" with new always-on behavior.
  * Removed some vertical zoom presets.
  * Removed EQ XML to TXT converter, which was needed for
    the Audacity 2.3 -> 2.4 transition. It is now a plugin instead,
    downloadable at https://plugins.audacityteam.org/additional-resources/eq-curves/eq-xml-to-txt-converter.
  * Removed the "Vocal reduction and isolation" effect. As a replacement
    on Windows and Linux, the Intel OpenVINO plugins work better and on
    a wider array of content, including mono tracks. The old effect still can
    be downloaded from https://plugins.audacityteam.org/nyquist-plugins/effect-plugins/filters-and-eq#vocal-reduction-and-isolation
  Bugfixes
  * Fixed a number of dialogs that were able to grow too large to
    fit on the screen.
  * #2133 Fixed the playback cursor sometimes desynchronizing with
    actual playback. (Thanks, David Bailes!)
  * #3723 #5615 Fixed the GetInfo scripting command.
  * #5283 Fixed "Reset configuration" command breaking modules preference page.
  * #5389 Fixed stereo tracks randomly splitting into mono.
  * #5500 The Export Audio -> (external program) option remembers
    the command line argument again.
  * #5670 #3903 Fixed the Compressor effect sometimes corrupting
    audio. (Thanks, David Bailes!)
  * #5580 #4952 Fixed Timer Record sometimes failing to export.
    (Thanks, David Bailes!)
  * #5681 Fixed incorrect level measurements for mono tracks in
    Noise Gate effect. (Thanks, Steve Daulton!)
  * #5750 When exporting multiple files, the mono/stereo setting is
    now honored properly.
  * #5848 Fixed some effects failing when language is set to German,
    Korean, Dutch, Slovenian, or Turkish.
  * #5868 #1548 Fixed 8 and 9 inputs not working on keyboard inputs which
    have AltGr+8/9 mean [ and ]. (Thanks, David Bailes!)
  * #5858 Fixed Audacity crashing when making a stereo track using
    keyboard. (Thanks, Joe Souza!)
  * #5976 Fixed the "Set default" button not working in the metadata
    editor. (Thanks, dg-no-9!)
  * #5977 Linux: Fixed a memory leak in Wayland by explicitly running
    on X11. (Thanks, Takahashi, Naoki!)
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Nov 17 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.4.2
  This is a hotfix release. It fixes the following issues:
    [#5568] Fix a crash when opening projects with zero-length clips.
    [#5032] When exporting a file, the sample rate of the tracks is
    now considered, and last-used sample rate is remembered.
    [#5555] Copy-pasting now pastes into audio again by default.
    This can be changed via Preferences -> Track Behavior ->
    Always paste audio as new clips.
    [#5549] Mix and render now also resets the gain for the
    resulting track.
    [#5571] Fix clips shifting to the right when effects are applied
    to them.
    [#5106] Fix clicks occurring when overdubbing a project with
    muted tracks.
    [#5533] Fix files being exported without a file extension in
    rare cases.
    [#5539] Show all sample rates possible for MP2 exports.
    [#5518] Fix pasting into labels.
    [#5543] Fix a crash when clearing loops.
    [#5529] Fix copying when "select all audio if selection required"
    is enabled.
    [#5598] #5552 Fix GTK detection and compilation for wxWidgets 3.2.4.
    [#5551] Fix Nyquist-related crashes.
    [#5604] Fix EQs in macros.
    [#5511] Fix a crash when closing Audacity.
    [#5476] Fix builds on armhf.
* Fri Nov 10 2023 ecsos <ecsos@opensuse.org>
- Use gcc12 in Leap to fix build error.
* Thu Nov  9 2023 Dave Plater <davejplater@gmail.com>
- Removed patches:
  vst-system-path.patch, vst3sdk-fix-include-cstdint.patch and
  vst3sdk-fix-std-atomic-for-gcc12.patch.
- Added patches:
  lib64-plugins-default-path.patch,
  vst3sdk-fix-limits-include-moduleinfoparser.patch and
  vst3sdk-fix-include-cstdint-for-gcc13.patch
* Wed Nov  8 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.4.1
  This is a hotfix release. It fixes the following bugs:
  * #5467 Fix 24-bit recording.
  * #5488 Fix a crash with .aup importing.
  * #5471 #5483 Fix crossfading of clips and tracks.
  * #5473 Exporting multiple files honors sample rate settings again.
  * #5480 #5417 Fix crashes related to external program exports.
  * #5479 #5476 Fix BSD and ARM builds.
  * #5498 Ctrl+J is now a standard shortcut for joining clips.
  * #5389 Stereo tracks no longer randomly split into mono.
  * #5007 When exporting a file, the file extension is now always
    added (except for custom FFmpeg and external program exports).
  * #5516 Fix a crash when exporting Opus with older CPUs that
    don't support AVX.
* Sun Nov  5 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- set vst3sdk to 3.7.7_build_19
- update patchset
- update dependencies in .spec
- Update to 3.4.0
  Major changes
  * Music workflows
    Audacity now features several music related features, such as
    switching between hh:mm:ss time and Beats & Measures, and
    time-stretching clips to align them to a song's tempo.
  * Time stretching
    Hold Alt (macOS: Option) while hovering over the top third
    of a clip edge to stretch it.
  * New exporter
    Audacity now features a new export window with easier access
    to options such as sample rate and custom mapping (for 5.1 or 7.1 audio).
    Additionally, the "Browse" button uses the native file browser now!
  Other changes
  * For MP3, Audacity now always uses Joint Stereo mode, which
    always delivers the best possible quality.
  * #4720 Simplified pasting logic.
  * Simplified stereo tracks. Left and right channels now always
    have synchronized clip starts and ends, and the same sample
    rate in both channels.
  * #5014 Added cursors trimming and stretching left and right,
    and changed the I-beam cursor to be less similar to either.
  * #4448 When importing audio, the project sample rate no longer changes.
  * #5204 The spectrogram colors are now perceptually uniform, and
    the colormap has gotten a name: Roseus. It also can be used
    for dataviz outside of Audacity, see https://github.com/dofuuz/roseus
    for more info! (Thanks, Myungchul Keum)
  * New defaults: The Time Signature toolbar now gets shown,
    the solo button is set to multi-track mode, time tracks have
    a wider starting range.
  * #5291 Unsquished the Audacity logo found in some places of the app.
  * #2330 Clicking on the border of two clips no longer merges them.
  * #2530 Overdubbing on Windows fails with WASAPI with default
    Recording device.
  * #443 Built-in Opus support.
  Libraries
  * lib-time-and-pitch implements a time stretching algorithm
    originating in Staffpad.
  * Audacity now uses Conan 2.
  * Continued extracting code into libraries and modules,
    especially in the context of importing and exporting.
  Bug fixes
  * #3778 --nogap metadata no longer is ignored.
  * #4410 fixed a crash with LV2 plugins (thanks jfroyall!).
  * #2471 #4798 fixed some crashes related to macros.
  * #4769 fixed a crash when pasting in certain configurations.
  * #4677 Accessibility: GUI can be disabled again for VST2
    plugins (thanks, David Bailes!).
  * #4988 Accessibility: Restored window control IDs, improving
    NVDA compatibility (thanks again, David Bailes!).
  * #4872 fixed a crash on launch on OSX 10.9 (thanks, René Bertin!).
* Wed Jul 12 2023 Andreas Schwab <schwab@suse.de>
- Update constraints for riscv64
* Thu Jun 22 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.3.3
- Downgrade vst3stk to 3.7.3_build_20 as most compatible with audacity
- Rework vst3sdk patches vst3sdk-3.7.3_build_20:
  remove vst3sdk-fix-include-cstdint-for-gcc13.patch,
    vst3sdk-fix-limits-include-moduleinfoparser.patch
  add vst3sdk-fix-std-atomic-for-gcc12.patch,
    vst3sdk-fix-include-cstdint.patch
- Add vst-system-path.patch changes vst(3) search path to /usr/lib64
  This is a hotfix release. It fixes the following bugs:
  * #4618 Fixed EQ not scaling properly when resizing the window.
  * #4743 Fixed the audio.com upload flow.
* Fri May 19 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.3.2
  This is a hotfix release. It fixes the following bugs:
  * #4629 Linux AppImage fails to start.
  * #4637 Issues with selection and time toolbars on Linux packages.
  * #4639 Missing duration input in generators on Linux packages.
  * #4646 Potentialy extreme memory usage with Jack host.
  * #4654 Anonymous upload to audio.com is disabled.
* Tue May  2 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Remove "changesgenerate" from _service for vst3sdk
- Update to 3.3.1
  This is a hotfix release. It fixes the following bugs:
  * #4600 Fixed cut lines massively inflating project size.
  * #4612 Fixed custom project sample rates being uneditable.
  * #4604 Fixed crash reporting being disabled.
  * #4234 Audacity now shows an error if the upload to audio.com
    exceeds file size limits.
  * #4114 Fixed an error in calculating channels when uploading to
    audio.com.
* Tue Apr 25 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Use default compiler, upstream has fixed gcc13 build
- Update VST3SDK to version 3.7.7_build_19:
- Add patches to fix VST3SDK build with gcc13:
  vst3sdk-fix-include-cstdint-for-gcc13.patch
  vst3sdk-fix-limits-include-moduleinfoparser.patch
- Remove patches  - fixed in upstream:
  no-more-strip.patch
- Refresh patches:
  audacity-no_return_in_nonvoid.patch
- Update to 3.3.0
  Changes
  * Some of the built-in effects are now realtime capable (Bass &
    Treble, Distortion, Phaser, Reverb and Wahwah).
  * #4352 Added a new effect: Shelf Filter.
  * Added an initial (beta) version of Beats and Bars.
  * #4414 Reworked the bottom toolbar dock:
  * Project Sample Rate is now found in Audio Setup -> Audio
    Settings (formerly known as Project Rate).
  * The Snapping Toolbar (formerly known as Snap-To) is now
    independent of the Selection Toolbar.
  * Added a new Time Signature Toolbar (beta). It is hidden by default.
  * #4212 Improved Zooming behavior slightly (more to come in the future).
  * #4393 Added a new ruler, Linear (dB). This ruler goes from
    0 dBFS to -∞ dBFS and better reflects the volume as shown in
    the recording/playback meters.
  * #3820 When copying clips between projects, you now can choose
    between whether to copy smart clips or just the visible portion.
  * #4133 Added a delete button to the Cut/Copy/Paste toolbar.
  Bugfixes
  * #1584 Audacity no longer dithers tracks unnecessarily.
  * #2427 Linux playback now handles output latency better (less stutters).
  * #3796 The EQ effect no longer resets clip names.
  * #3801 Audacity no longer crashes when trying to load projects with
    plugins that since have been deleted.
  * #4417 Resampling a track no longer trims it.
  Libraries
  * FFmpeg 6 (avformat 60) is now supported.
  * Moved from Breakpad to Crashpad.
  * Extracted various libraries from within Audacity.
* Wed Apr  5 2023 Dave Plater <davejplater@gmail.com>
- Use gcc12 to build until upstream has caught up with gcc13
- Update to 3.2.5
  This is a hotfix release. It fixes the following bug:
  [#4373] Fixes authorization flow for the audio.com sharing service
* Fri Feb  3 2023 Takashi Iwai <tiwai@suse.com>
- Update to 3.2.3:
  This is a patch release for Audacity 3.2. It adds ability to share
  audio publicly and fixes some bugs.
  * #3884 Audio can now be shared publicly on audio.com
  * #4040 Fixed the screenshot tool
  * #4019 Selecting audio no longer marks the project as changed
  * #3693 A new toolbar with cut/copy/paste buttons has been added
  * #3216 Plain UI for VST3 plugins no longer show MIDI CC parameters
  * #2620 The effects sidebar no longer can fill the entire screen
- Update to 3.2.4:
  This is a hotfix release. It fixes the following bug:
  * #4057 Fixed the meters not retaining size
- Increase the constraints to avoid OOM at the build time
* Tue Dec 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(gtk+-2.0) with pkgconfig(gtk+-3.0)
  BuildRequires, audacity have moved to gtk-3 several versions ago.
* Thu Dec  8 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.2.2
  This is a patch release for Audacity 3.2. It enables use of VST2 as
  realtime effects and fixes some bugs.
  * #2850 VST2 effects are now realtime capable.
    Additional plugins have been added to plugins.audacityteam.org
  * #3696 Improved accessibility of the meters
  * #3769 Fixed a crash when editing some macro parameters
  * #3792 Fixed some play commands getting stuck in play mode
  * #3670 Audacity no longer quietly discards changes in realtime
    effects but instead asks if you want to save before quitting
  * #3838 Plugin scanning now lets you skip individual plugins if
    scanning gets stuck on them
  * #3980 Plugin scanning no longer produces "Audacity crashed"
    windows when a plugin fails validation,
    and no longer shows the plugins in the macOS dock during validation
  * #3883 Fixed an issue with labels losing focus on macOS Ventura
  * Fixed various plugin-specific issues
* Sun Oct 16 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- No more bundled custom wxWidgets, so remove them from the .spec completely
* Fri Oct 14 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Fix build for Leap 15.3
* Tue Oct 11 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- update spec, install audacity libs into _libdir/audacity
- update build deps - no need for carla
- don't create lame.pc
- use %%cmake_build
* Fri Oct  7 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- add patch:
  mod-script-pipe-disable-rpath.patch
- update audacity-rpmlintrc
* Fri Oct  7 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- remove patches, now upstream:
  0001-Call-the-proper-wxBitmap-constructor-for-XPM-data.patch
  0001-Remove-custom-languages-in-wx-3.1.6-and-above.patch
  missing-include.patch
- refresh patches:
  audacity-no_buildstamp.patch
  audacity-no_return_in_nonvoid.patch
  no-more-strip.patch
- update licenses
- Update to 3.2.1
  Changes in version 3.2.1
  This is a patch release. It fixes some bugs and has minor improvements.
  * #3686 Fixed Audacity crashing on startup on some systems.
  * #3694 Fixed a crash when applying Waves Berzerk Distortion
    Mono to a mono track
  * #3699 Fixed a freeze when very quickly starting and stopping
    playback.
  * #3747 macOS: Homebrew FFmpeg installs are now found automatically
  * #3594 macOS: Fixed Melda VST Plugin UI
  * #3474 Building with VST3 support is now possible without Conan.
  Changes in version 3.2.0
  This version adds realtime effects and VST3.
  Prominent changes
  * Added a new Effects button to the tracks menu, allowing you to
    place realtime effects.
    Further information can be found can be found on
    https://support.audacityteam.org/audio-editing/using-realtime-effects
  * Merged the mixer bar with the meter bars.
  * Added a new Audio Setup button, replacing the Device Toolbar
    by default. The device toolbar can be re-added via the
    View > Toolbars menu.
  * The Effects menu has gotten a new sorting. Other sorting and
    grouping options can be found in the Effects preferences.
  * Updated the icons.
  * Added a quick audio sharing feature.
    More info can be found on https://support.audacityteam.org/basics/sharing-audio-online
  Plugin changes
    You can find plugins on https://plugins.audacityteam.org
  * VST3 effects are now supported.
  * The following plugin formats are now realtime capable:
    VST3, LV2, LADSPA, Audio Units.
  * Plugins now automatically get scanned, tested and enabled
    when Audacity starts.
  System changes
  * Apple Silicon (arm64) is now supported on macOS
    Note: When using an arm64 Audacity, you must use arm64
    versions of FFMPEG and plugins. Plugins for x86-64 (Intel macs) will not load.
    For the time being, Audacity will continue to download
    x86-64 versions by default to avoid these incompatibilities,
    but you can download an arm64 version from Github releases:
    https://github.com/audacity/audacity/releases
  * FFMPEG 5.0 (avformat 59) is now supported, in addition to
    avformat 55, 57 and 58
  * Added support for Wavpack
  * On Linux, Audacity can now be compiled without JACK present.
  * Audacity now uses XDG directories on Linux.
    Note: If you are upgrading from a previous version,
    Audacity will keep using the ~/.audacity-data and ~/.audacity folders until you delete them.
  * Switched from mad to mpg123 as MP3 importer
  License update
  * Audacity binaries are now licensed under the
    GNU General Public License, Version 3.
    Most code files remain GPLv2-or-later, but VST3
    support required this license update.
    More information can be found in the announcement
    post: https://github.com/audacity/audacity/discussions/2142
  Removals
  * Removed the Zoom Tool. You can use the zoom buttons
    or Ctrl+Scroll (macOS: Cmd+Scroll) to zoom instead.
  * The Audacity Manual HTML pages are no longer included
    in the installation.
    If you require offline access of the manual, you can download
    it here: https://github.com/audacity/audacity-manual/releases
    You also can download PDFs of https://support.audacityteam.org
    straight from its sidebar (or the three-dot button on mobile devices).
  Fixed bugs:
  * #3079 Fixed Audacity sometimes not being able to import MP3
    files (or reporting Huffman Data Overruns)
  * #2590 Fixed rare data loss bug when placing labels during recording
  * #2272 Fixed clip titles being able to disappear off-screen when editing them
  * #2162 Fixed Punch and Roll not paying tracks in sync
  * #1889 Fixed clip titles changing name when applying some effects
  * #1624 During batch processing, Audacity will no longer stop to ask
    for a sample rate when an unsupported one is chosen, but choose the
    nearest supported one instead.
  * #2265 Fixed mod-script-pipe not being installed on Linux
  * #3571 Fixed GTK packaging in Appimages. This fixes various issues with
    icons, dropdowns and similar things not appearing properly.
  * #3634 Improved M4A/AAC support. Previously the target bitrate was
    not honored at all, now it can be set between 98 and 160 kbit/s (mono)
    or 196 and 320 kbit/s (stereo). The UI does not yet reflect these limits.
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- #error All sample block data is little endian...big endian not yet supported
  Disable s390x builds.
* Mon May  2 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on non-x86_64 by not requiring carla-devel
* Wed Apr 27 2022 Dave Plater <davejplater@gmail.com>
- Fix build with new carla by requiring carla-devel
* Tue Apr 26 2022 Dave Plater <davejplater@gmail.com>
- Really solve boo#1198551 by packaging audacitie's libraries in
  _libdir
* Thu Apr 21 2022 Dave Plater <davejplater@gmail.com>
- Add ldconfig post and postun for audacity's own libs to solve
  boo#1198551
- Fix audacity's build against wxWidgets 3.1.6 with two patches
  from git:
  0001-Remove-custom-languages-in-wx-3.1.6-and-above.patch and
  0001-Call-the-proper-wxBitmap-constructor-for-XPM-data.patch
* Thu Apr 14 2022 Dave Plater <davejplater@gmail.com>
- Added libopus build dependency and "-DCMAKE_SKIP_RPATH:BOOL=on"
  to fix Leap builds.
* Wed Apr 13 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 3.1.3
  * remove patches, now upstream:
    0001-Adds-an-option-to-disable-Conan.patch
    0001-Fixes-wxwidgets-fixup-script.patch
    0001-Scope-libraries-required-by-the-optional-features.patch
    Refresh missing-include.patch
  * Improved performance of loading in projects
  * Added snap guides when resizing clips
  * Added new shortcuts for looping:
    Shift+L for "Set Loop to Selection",
    Shift+Alt+L for "Clear Looping Region"
  * Added a new selection region indicator in the timeline
  * Re-added the Quick Play indicator
  * Lot of bug fixes
* Mon Jan 31 2022 Dave Plater <davejplater@gmail.com>
- Added conditional %%post and %%postun for Leap, to fix boo#1194977
* Fri Dec  3 2021 Marcus Rueckert <mrueckert@suse.de>
- prefer more system packages
  - sqlite3
  - portmidi
  - portaudio
- add some missing includes: missing-include.patch
- make sure we no longer strip the binaries: added
  no-more-strip.patch
- audacity_use_ffmpeg=linked no longer works. switch to loaded.
- bump from c++11 to c++17 (as the package now requires a c++17
  compiler)
- drop patches:
  0001-Adds-an-option-to-disable-Conan.patch
  0001-Fixes-wxwidgets-fixup-script.patch
  0001-Scope-libraries-required-by-the-optional-features.patch
  Fixes-GCC11-compatibility.patch
  audacity-misc-errors.patch
- refresh patches:
  audacity-no_buildstamp.patch
  audacity-no_return_in_nonvoid.patch
* Fri Dec  3 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 3.1.3~beta1
  This is a hotfix release. It improves project performance
  significantly (up to 50x) compared to 3.1.0, and fixes the
  following bugs:
  - Fixes a crash when releasing a clip handle #2147
* Fri Dec  3 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 3.1.2
  This is a hotfix release. It fixes the following bugs:
  - Fixed UTF8 support in clip titles #2135
  - Fixed data loss when joining clips #2123
  - Fixed a crash with exporting resampled tracks #2136
  - Fixed a crash when opening projects with very small double
    values #2128
- Update to 3.1.1
  This is a hotfix release. It fixes the following bugs:
  Other than that, this release is identical to Audacity 3.1.0
  - Fixed FFMPEG imports only importing the left channel #2046
  - Improved Audacity's performance when many clips are present
  - Fixed a crash with detach at silences #2072
  - Fixed clip name corruption when applying effects to adjacent
    clips #1889
  - Fixed a crash with the time shift commands #2061
  - Fixed custom themes not working #2043
- Update to 3.1.0
  This release introduces clip handles, smart clips and playback
  looping as its major new features.
  Smaller changes:
  - Context menus have been added in more places.
  - In the preferences, Tracks > Track behaviors > Editing a clip
    can move other clips is now disabled by default
  - The spectrogram defaults have been changed: scale type to Mel
    (was Linear), top of scale to 20000 Hz (was 8000 Hz), window
    size to 2048 (was 1024), and zero padding to 2 (was 1).
  - The main volume controls no longer change the system volume.
  - Raw Import now will remember the previously used settings.
    Automatic detection of the format now is a button.
  - A journaling feature has been added for QA purposes.
  - Generate > Tone now supports triangle waves.
  - There now exist "What's new" screens for the update and welcome
    dialogs.
  - Timeline Quick Play for regions and locked regions have been
    replaced by playback looping.
  - The shortcut to rename labels and clip names has temporarily
    been hardcoded to Ctrl+F2.
  - This conflicts with the default xfce shortcut to change
    workspaces. Library changes:
  - FFMPEG now supports avformat 55, 57 and 58.
  - PortAudio has been updated to version 19.7 and devendored (so
    it can be built against 19.6).
  - Several libraries (expat, libsndfile, ...) have been
    devendored. The CMakeLists.txt lists which versions we build
    against. Fixed Bugs: There are some 50 issues closed labeled as
    bug. Among them:
  - AppImages support localization. #1382
  - Progress bars for Nyquist generators have been made more
    accurate. #1856
  - Rhythm tracks can no longer drift off-time by 2ms over 9
    minutes; they're now sample-accurate. #1853
  - The play button has regained a pixel or two to become a
    triangle once more. #1792
  - Auto Duck has been made way more accurate and should no longer
    miss sections above the threshold. #1389
  - The manual now only is included in the executable once #1917
  - Shift-clicking a menu item no longer opens the settings menu
    [#1358]
  - FFMPEG no longer segfaults ALSA #1170
  - Audacity no longer crashes when macros output directory is set
    to C:\ #1174
  - A bouncing ball of death problem has been fixed #1312
* Tue Nov 30 2021 Dave Plater <davejplater@gmail.com>
- Remove pipewire-libjack-0_3 conflict. pipewire-libjack-0_3's
  latest version is fixed.
* Fri Nov 26 2021 Dave Plater <davejplater@gmail.com>
- Conflict pipewire-libjack-0_3 to prevent boo#1191585
* Sat Oct 16 2021 Dave Plater <davejplater@gmail.com>
- Update to release 3.0.5.
- Upstream changes:
  * Fix bug 1571.
  Convert to C locale decimal point for stable parsing.
  * Download manual from GitHub.
  * Set release version to 3.0.5 in preparation of hotfix.
* Fri Aug 27 2021 Dave Plater <davejplater@gmail.com>
- Update to version 3.0.4
- Add git patches:
  0001-Adds-an-option-to-disable-Conan.patch,
  0001-Scope-libraries-required-by-the-optional-features.patch
  0001-Fixes-wxwidgets-fixup-script.patch
- Added patch adapted from git, Fixes-GCC11-compatibility.patch
- Removed obsolete patches, audacity-remove-wx-test.patch and
  b4b5cc8.patch
- Upstream changes:
  * This is a hotfix release that fixes a bug with envelope points,
  which could multiply uncontrollably and cause Audacity to crash.
  * In particular:
    [#1476]: Envelope points are multiplied when using
    Filter Curve EQ or Graphic EQ
    [#1477]: Filter Curve EQ will crash if there is an envelope
    point outside of the selection
  * This fix re-introduces an earlier, but way less destructive bug:
  bugzilla 208 / #1500: Some effects delete Envelope Control Points
  or do not move them when timeline changes
  * Other than that, this release is identical to Version 3.0.3.
* Wed Jul  7 2021 Marcus Rueckert <mrueckert@suse.de>
- added https://github.com/audacity/audacity/commit/b4b5cc8.patch
  Fix jack detection which got broken in 3.0.2 (boo#1187788)
* Mon Jun  7 2021 ecsos <ecsos@opensuse.org>
- Fix build error for Leap 15.1 and 15.2.
* Mon Apr 19 2021 ecsos <ecsos@opensuse.org>
- Update to 3.0.2
  * Audacity 3.0.2 fixes some important bugs and improves diagnostic
    reporting.
  * We also added a new preference for macro output,
    and a 'Save' button on the manage macros dialog.
- Rebase audacity-no_buildstamp.patch.
* Thu Apr  8 2021 Dave Plater <davejplater@gmail.com>
- Update to release 3.0.0 and add patch for wxWidgets test:
  audacity-remove-wx-test.patch
- Add another useless return after assert to:
  audacity-no_return_in_nonvoid.patch
- Upstream changes:
  * Audacity 3.0.0 is a major update on our previous release
  We’ve changed the format in which we save Audacity projects!
  Previously we saved projects as a sometimes large number of small
  files, with an ‘.aup’ file to coordinate the lot. This way of
  doing things is sometimes called ‘pile of files’ storage.
  * We did have time to improve our ‘Noise Gate’ effect and add a
  new analyzer, ‘Label Sounds’, that can label sounds and silences
  We also made a few small tweaks elsewhere. You can now import
  and export macros, and there are a couple of new commands for
  using the last used tool or last used analyzer that you can give
  shortcuts to.
  * We also fixed over 160 bugs that had been accumulating over the
  years. This is quite a staggering amount of work. The majority
  of these bugs were minor problems, easily worked around.
  Some though were really juicy high priority bugs that would have
  mattered a lot to the people affected by them. We’re really glad
  to have these bugs fixed now.
* Thu Oct  1 2020 Dave Plater <davejplater@gmail.com>
- Remove build requirement for libwx_gtk3u_core-suse-nostl3_1_3 as
  it is no longer needed and it prevents Factory build.
* Sat Aug 29 2020 Dave Plater <davejplater@gmail.com>
- Remove libavformat symlink and remove the plugins sub package.
  The symlink is obsoleted by linking to ffmpeg rather than
  dlopening it. The plugins were caused by the wrong suil version.
* Wed Aug 26 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for min 6GB physicalymemory for ppc64/ppc64le
* Wed Aug 26 2020 Jan Engelhardt <jengelh@inai.de>
- Link to ffmpeg rather than dlopening it.
* Thu Aug 20 2020 Dave Plater <davejplater@gmail.com>
- Create symlink for libavformat, audacity looks for the major
  version only and this no longer exists in openSUSE after
  ffmpeg-4.3.1. See boo#1175205
* Sun Jul  5 2020 Markus Reckwerth <marec@detebe.org>
- fixing dependencies for leap 15.2
* Sun Jun 28 2020 Dave Plater <davejplater@gmail.com>
- Update to 2.4.2, now uses cmake to build.
- Create lame.pc in spec file.
- Remove audacity-implicit-fortify-decl.patch and
  audacity-flacversion.patch, fixed upstream
- Add two more false positives to
  audacity-no_return_in_nonvoid.patch
- Upstream changes:
  * Over 30 bugs fixed since 2.4.1
  * A new command has been added to the Tools menu:
  Tools > Reset Configuration.
  * Audacity now supports LAME's gapless playback info, allowing
  MP3s to be exported and imported without additional padding.
* Mon Jun 15 2020 Dave Plater <davejplater@gmail.com>
- Fix Leap:15.1 build with audacity-implicit-fortify-decl.patch.
* Mon Jun  8 2020 Dave Plater <davejplater@gmail.com>
- Update to release 2.4.1 and remove:
  0001-Bug2436-Cross-project-paste-should-duplicate-block-f.patch
- Now needs wxWidgets >=3.1.1 to build.
- Upstream changes:
  * A new Time Toolbar showing current record/playback time has been
    split from the Selection Toolbar.  It can be resized large.
  * Presets for more effects can be imported and exported.
  * A new Multi-View mode for tracks.  In this mode both
    spectrogram and waveform views are shown at the same time.
  * Opus available as a new audio export format on Windows and Linux.
  * Easier to convert labels between point labels and range labels.
  * New Loudness Normalization effect.
  * New RMS measurement analyzer.
  * New Noise Gate effect.
  * New Spectral Delete effect.
  * 2237 - Equalization effects have no Import or Export for curves
  * 2261 - Graphic EQ sliders have no frequency labels
  * 2265 - Track heights are reset to default on project re-opening
  * 2303 - Playback does not start at the saved cursor position on
    reopening a saved project.
  * 2314 - Zoom in fail when playing
  See also:
  https://wiki.audacityteam.org/wiki/New_features_in_Audacity_2.4.1
* Mon May 18 2020 Dave Plater <davejplater@gmail.com>
- Update to release 2.4.0 and rebase audacity-no_buildstamp.patch.
- Add patch from git:
  0001-Bug2436-Cross-project-paste-should-duplicate-block-f.patch
- Add plugins sub package.
- Upstream changes:
  * have split the recording/playing time off from the selection
  toolbar and it can now be dragged to make it larger.
  * added a new optional mode for viewing audio. In this new mode
  you can see both the waveform and a spectrogram at the same time.
  Previously you would switch back and forth between them if you
  wanted both.
* Thu Feb 13 2020 sbrabec@suse.com
- Fix invalid RPM group.
* Mon Feb  3 2020 Dave Plater <davejplater@gmail.com>
- Download 2.3.3 tarball again to fix incorrect release info.
- Use autopatch and refresh patches.
- Fix boo#1162418, caused by wxWidgets.
* Mon Nov 25 2019 Dave Plater <davejplater@gmail.com>
- Update to release 2.3.3
- For upstream changes see:
  http://wiki.audacityteam.org/wiki/Category:Release_Notes
* Mon Oct 21 2019 Dave Plater <davejplater@gmail.com>
- Create a more suitable Group: tag.
* Tue Aug  6 2019 Dave Plater <davejplater@gmail.com>
- Update to release 2.3.2
- Upstream changes:
  * Improvements:
  * There is a new 'Select' button in the track panel to select the
  whole track.
  * Audacity mod-script-pipe for driving Audacity from Python now
  comes with Audacity and can be enabled via preferences.
  * Options and preferences:
    Type to Create a Label is now off by default.
  * A plug-in installer for Nyquist now provides a file browser for
  selecting '.NY' files to install.
  * Bug Fixes:
  Over 20 bugs in 2.3.1 fixed, including:
  * Audacity 2.3.1 would crash if append-recording to a collapsed
  track.
* Mon Mar 11 2019 plater <davejplater@gmail.com>
- Update to release 2.3.1 and remove incorporated patch:
  0001-Fix-bug-1992.patch.
- Upstream changes:
  Over 20 bugs fixed since 2.3.0, including:
  A crashing bug on Linux that made Audacity 2.3.0. unsuitable for
  Linux.
  Problems with Change Pitch, including not remembering parameter
  values.
  Options and preferences:
  Microfades are now an opt-in feature. They were always on in
  2.3.0.
  The advanced vertical zooming option is now available in the
  View->Zoom menu.
  Regular interval labels now support range labels.
* Wed Oct  3 2018 davejplater@gmail.com
- Add 0001-Fix-bug-1992.patch from git to fix issue 1992
* Mon Oct  1 2018 davejplater@gmail.com
- Update to release 2.3.0
- Rebased audacity-misc-errors.patch and
  audacity-no_return_in_nonvoid.patch
- Added --disable-dynamic-loading build flag for ffmpeg-4 use.
- Upstream changes:
  * New feature – “Punch and Roll Recording”
  * Pinned-play-head can now be repositioned by dragging
  * Play-at-speed now can be adjusted whilst playing.
  * Toolbars controlling volume and speed can now be resized for
  greater precision
  * New commands: New ‘Tools’ menu & New ‘Scriptables’ commands
  * Nyquist gains AUD-DO command
  * Nyquist effects are now translatable and translated
  * More dialogs have help buttons now
  * Increased legibility of trackname display
  * Half-wave option for collapsed tracks
  * Sliding Stretch
  * Dialog (option) for entering labels
  * Inconsistent behavior when recording with a selection–bug #1839
  * Ctrl + M does not open label for editing – bug #1852
  * Vertical Zoom in by clicking in the vertical Scale, or context
  menu, in waveform views is inconsistent – bug #1810
  * Deletion of all tracks cannot be undone – bug #1845
  * Timer Record with a selection present can get a truncated
  recording with data loss – bug #1851
  * Duplicate shortcuts can be created – bug #1786
  * Labels longer than 260 characters are now supported – bug #1905
  * Using Spectrogram Settings in TCP or using Preferences causes
  Audacity to reset Project Rate to default rate in Quality
  Preferences – bug #1977
  * Cut Preview should play all selected/sync-locked tracks,
  respecting Mute/Solo during preview – bug #231
* Sun Apr 29 2018 davejplater@gmail.com
- Ensure that Leap:42.3 gcc conditional doesn't interfere with
  Tumbleweed gcc used for build.
* Thu Feb 22 2018 davejplater@gmail.com
- Update to release version 2.2.2.
- Rebase audacity-no_buildstamp.patch.
- Removed incorporated audacity-fix-nonsense.patch.
- Added audacity-misc-errors.patch to fix various errors picked
  up by rpmlint.
- Added to audacity-no_return_in_nonvoid.patch.
- Upstream changes:
  * Easier zooming in and out with mousewheel, new Zoom Toggle
  command, and context menu for vertical rulers.
  * Easy access to change keyboard bindings of menu commands
  by holding Shift key.
  * Detection of dropout errors while recording with
  overburdened CPU.
  * Improved contrasts in Light and Dark themes
  * Half-wave display option
  * Several bugs/annoyances in 2.2.1 are now fixed
* Fri Jan 26 2018 davejplater@gmail.com
- Build with gcc7 for Leap:42.3 and -fstack-clash-protection
* Mon Jan 15 2018 jengelh@inai.de
- Trim redundant parts from summary.
* Mon Jan 15 2018 davejplater@gmail.com
- Update to maintenance release version 2.2.1
- Upstream changes and fixes:
  * Waveform colorways:
  You can optionally change the colorway of the waveforms
  displayed in your project. The setting is per track and not per
  project so you can have multiple colorways in the same project.
  * "Save Other" reverts to "Export" in the File menu:
  When we made the menu changes for 2.2.0 we introduced an entry
  into the File menu called "Save Other" which led to a sub-menu
  for exporting various audio formats.
  Many users were confused by this change and found it hard to
  find where they could export.
  * Bug #1770 - Crash applying certain chain files
  * Bug #1783 - Preview fails when selection extends before zero
  * Bug #1787 - Auto-scroll stopped working in 2.2.0
  * Bug #1765 - Using File > Open to import audio gives wrong zoom
  level and no scroll bar slider.
* Sun Nov  5 2017 davejplater@gmail.com
- Enabled mad, twolame and lame for 42.3
* Sun Nov  5 2017 aloisio@gmx.com
- Update to version 2.2.0
  Improvements:
  * Four Selectable themes provided, with new 'Light' theme as
    default, plus option to customize
  * Many menu changes:
    + Menus Reorganized
    + Extended menu bar provided
    + New keyboard commands for working with clips
  * Help buttons ? in Preferences, Effects, Generators and
    Analyzers - and other places
  * Non-Greying out of effects when no selection (and explanatory
    dialog with help button)
  * Playback of MIDI (and Allegro) files imported into Note Tracks
    is now available.
  * 'Center' option in Selection Toolbar
  * Stem plots
  * Major overhaul to documentation/manual including many new
    images and streamlined text on landing pages for in-program
    help.
  Other Changes:
  * Append-record is now the default (use Shift + Record for old
    behavior, to record on a new track)
  * The Esc key now cancels all click-and-drag actions. It also
    chooses among overlapping mouse click targets, which is
    especially useful in the Multi-Tool.
  * Sync-Lock button removed (use menu item or keyboard shortcut
    instead)
  * New preferences and preference pages
  * Overhaul of much code:
    + Overhaul of envelope handling code to deal with some
    anomalies
    + Overhaul of exception handling for greater safety
  * New Logo
  Bug Fixes:
  * Major work on bug fixing. 198 bugs that were in 2.1.3 fixed
    for 2.2.0.
    + The most serious bug fixed this time round was bug 437 which
    was about what happens when Audacity is recording and runs
    out of storage.
    + The problems of incomplete support for macOs Sierra have
    been resolved (including bug 290, bug 1567, bug 1702, and bug
    1703).
    + Most of the bugs fixed were more minor, such as bug 463
    which was about a case in which the numbering on the timeline
    could display incorrect times.
- Added audacity-no_return_in_nonvoid.patch
* Fri Aug 25 2017 davejplater@gmail.com
- Restore conditionals for lame, mad and twolame.
* Fri Aug 25 2017 olaf@aepfle.de
- Remove conditionals for ffmpeg, lame, mad, twolame.
* Tue Jun  6 2017 olaf@aepfle.de
- Adjust usage of gccN-c++ for Leap42 and SLE12
* Wed Mar 22 2017 davejplater@gmail.com
- Added requires for flac > 1.3.0.
* Sat Mar 18 2017 davejplater@gmail.com
- Update to release 2.1.3
- Recreated audacity-no_buildstamp.patch with 2.1.3 release date
  and time.
- Added audacity-flacversion.patch to fix minimum version in m4
  macro.
- Rebased audacity-fix-nonsense.patch
- Deleted audacity-ffmpeg.patch, audacity-flac_assert.h.patch and
  audacity-gcc6.patch
- Upstream changes:
  * Interface:
  * Pinned option on waveform so waveform moves and
    recording/playing head stays still.
  * Timer Record options to save/export/exit after recording.
  * Scrub Ruler and optional Scrub Toolbar.
  * New shortcuts ALT+RIGHT and ALT+LEFT (move to labels without
    editing).
  * Effects:
  * Effects no longer grayed out when paused.
  * New Distortion effect (replaces Leveller).
  * SBSMS (higher quality but slower) option on Change
    Tempo/Change Pitch effects.
  * New Rhythm Track generator (replaces Click Track).
  * New Generator for Sample Data Import.
  * Nyquist effects now significantly faster.
  * Other Changes:
  * Upgraded the PortAudio library to v19 rev r1966.
  * Bug fixes:
  * Over 60 bugs fixed, including five longstanding bugs.
* Mon Jun 27 2016 davejplater@gmail.com
- Update to audacity-2.1.2 which builds with wxWidgets-3_0-nostl
  and can use rpm's internal dependency generator. This enables it
  to provide appdata.xml and desktop files and fixes boo#952324 and
  duplicate boo#963592.
- Refreshed patches.
- Removed audacity-2.1.1-fix-tempdir.patch incorporated in this
  version.
- Upstream changes:
  Changes and Improvements:
  * Interface:
  * Spectrogram settings are now available per track.
  * Clearer (sharper) display of pitch (EAC).
  * New 'Spectral Reassignment' option in spectrogram.
  Bug fixes:
  * Crashes
  * Crash using 'space' in Selection toolbar context menu fixed.
  * Crash setting equalization effect parameters in chains fixed.
  * Crash pressing both mouse buttons over toolbar buttons fixed.
  * (Rare) crash or freeze in sound activated recording fixed.
  * (Rare) crash on using plot spectrum for first time fixed.
  * Interface
  * Equalization effect settings are now saved.
  * Oversized Export Options window now OK on smaller screens.
  * FLAC import/export fast again.
  * Can now set undefined frequency in Spectral Selection bar.
  * Imported presets on custom FFmpeg export fixed.
  * Text input boxes working with VAMP
  * Keyboard playback commands now work again.
  * Import Raw Data now works when in Polish language.
* Fri Jun 17 2016 martin.liska@suse.com
- Add audacity-gcc6.patch: Fix GCC6 warnings.
* Sun Apr 24 2016 sor.alexei@meowr.ru
- Add audacity-2.1.1-fix-tempdir.patch from upstream: fix usage of
  custom temp directories (boo#976964).
* Sun Oct 25 2015 sor.alexei@meowr.ru
- Fix audacity-flac_assert.h.patch up a little.
- Build with ffmpeg support in openSUSE Leap 42.1 and newer.
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Jul 20 2015 tiwai@suse.de
- Drop sf.net download URL as the download host was changed
* Sat Jul 18 2015 sor.alexei@meowr.ru
- Update to 2.1.1:
  + Changes and Improvements:
  * Built-in effects now support presets.
  * New Limiter effect replaces Hard Limiter effect.
  * New Crossfade Clips effect to apply a simple crossfade to a
    selected pair of clips in a single audio track.
  * Can now add/remove effects from Generate and Effects menus.
  * New version of Vocal Removal Effect.
  * Classic Filters now included as an opt-in effect.
  * Much faster editing with larger projects, thanks to a faster
    method for storing the autosave recovery file.
  * Performance improvements for Draw Tool and zooming of
    Spectrogram views.
  * Zero-padding Spectrograms Preference smooths the image for
    short window sizes.
  * Scrubbing and Seeking, including backwards play.
  * Quick-Play from Timeline enhancements, particularly for
    looping.
  * More VI usability enhancements for track focus & navigation.
  * Upgraded to Nyquist 3.0.9 and libflac 1.3.1.
  * Upgraded LV2 libs, LV2 GUIs on Linux, LV2 factory Presets.
  * Crash report integration.
  * Modules can be enabled in Preferences. Mod-nyq-bench
    available as an experimental module (but not in the default
    download).
  + Bug fixes:
  * Crash using Undo while dragging sample points
  * Crash using File > Close on project window when
    Screenshot Tools was open.
  * FFmpeg Custom Export: Crashes importing presets.
  * TAL VST (but not other VST's) crashed if previewing built-in
    effect.
  * SPACE could not be used/could crash in context menus that
    have a checkbox.
  * LV2 effects did not use parameters when using Chains.
  * Built-in Generators were not usable in Chains.
  * Plot Spectrum could not change values without losing focus.
  * Track dropdown menu settings could affect other tracks.
  * Slight mismatch of vertical scale with linear spectrogram
    view.
  * RTP effect Play/Stop button remained deactivated after
    built-in preview ended.
  * Contrast: "Move forward or backward through active windows"
    did not refocus Contrast.
  * LADSPA and LV2 generate plug-ins failed when white space
    selected.
- Rebase audacity-no_buildstamp.patch.
- Add audacity-fix-nonsense.patch to fix build regressions
  introduced in Audacity 2.1.1.
- Audacity now requires libsoxr without an option.
- Specify a version of wxWidgets Audacity requires.
* Wed Apr 29 2015 sor.alexei@meowr.ru
- Use libsoxr for resampling instead of libsamplerate.
* Mon Mar 30 2015 sor.alexei@meowr.ru
- Update to 2.1.0:
  + Changes and Improvements:
  * LADSPA and VST effects now support real-time preview,
    save/load of user presets and saving effect settings across
    sessions. Note: Real-time preview does not yet support
    latency compensation.
  * VST effects now support import/export of FXB preset banks.
  * Shell VST effects that host multiple plugins are now supported.
  * All Effect Menu items (built-in or plugin) can now be used in
    a Chain.
  * Items in the Effect, Generate or Analyze Menus can be sorted
    or grouped by name, publisher or class of effect.
  * Noise Removal is improved and renamed to "Noise Reduction".
  * Change Speed has new time controls for current and new length.
    You can now enter the speed change as a multiplier e.g. "2" is
    twice as fast.
  * New "Crossfade Tracks" effect can be used for crossfading two
    tracks. This replaces Cross Fade In and Cross Fade Out.
  * Nyquist Prompt and most shipped Nyquist effects now have
    Preview button.
  * Redesigned Meter Toolbars: The default shows separate Record
    and Playback Meters, half-height so they can be wider while
    docked, in gradient style.
  * A frequency selection can now be made (and spectral edit
    effects applied to those frequencies) when in a spectrogram
    view. You can also create or adjust frequency selections in a
    new "Spectral Selection Toolbar" (available at View > Toolbars).
  * Transcription Toolbar (Play-at-speed) can now loop play and
    cut-preview.
  * Timer Record now saves recordings automatically into an
    existing project.
  * New Armenian translation.
  + Bug fixes:
  * Typing "j" or "k" in a label track activated the
    "move cursor" shortcut.
  * Spectrogram log (f) view displayed incorrectly until
    vertically zoomed.
  * Fixed crash after zooming out on vertical scale beyond +/-1.0.
  * Selections made with Selection Toolbar were not restored after
    Undo.
  * Undo could fail silently if a selection included/touched a
    clip boundary.
  * If there were invalid FFmpeg libs in system PATH this
    prevented Audacity recognising the installed FFmpeg or the
    FFmpeg specified in audacity.cfg.
  * Fix "Audacity already running" error when using the
    command-line or context menu to open multiple or further files.
  * Fix segfault exporting an FFmpeg format to an unwritable folder.
  * Fix silent failure exporting FFmpeg, MP2 or OGG to an
    unwritable directory.
  * Fix ENTER activated an effect when OK button was greyed out.
- Add audacity-lang package.
- Extend audacity-flac_assert.h.patch to versions until 1.4.0.
- Do not remove appdata.
- Spec cleanup.
* Tue Mar  3 2015 joerg.lorenzen@ki.tng.de
- Add patch audacity-ffmpeg.patch to build against current ffmpeg
  on PMBS.
* Mon Oct 27 2014 joerg.lorenzen@ki.tng.de
- Fix download url for source package
* Fri Oct 24 2014 joerg.lorenzen@ki.tng.de
- Update to 2.0.6:
  Bug fixes for:
  * Interface:
  * Region Restore did not restore the region after using Preferences.
  * Dragging selections with the keyboard or Selection Toolbar digits
    was very slow.
  * (Windows) Help > About Audacity crashed when run in Magyar language.
  * (OS X) Some full and reduced Menu Bar items were not translated.
  * (OS X and Linux) Fixed various interface crashes.
  * Effects:
  * Reverb and Paulstretch were missing from Chains.
  * Analyze > Contrast could report very inaccurate rms levels.
  * Noise Removal: Attack and decay times were half as long as set.
  * (OS X and Linux) Nyquist effects ran much more slowly than on Windows.
  * Click or drag on the Timeline after Loop Play continued to loop.
  * Transcription Toolbar did not play slower than 0.1x speed.
  * (Linux) Audacity did not build if python 2 was not available.
  Changes and Improvements:
  * Interface:
  * Redesigned, searchable Keyboard Preferences with Tree, Name and Key views.
  * Edit Menu: "Cut" and "Delete" are now in the top level of the menu.
  * Transport Menu now includes "Play/Stop" and "Play/Stop and Set Cursor"
    (use Keyboard Preferences to create shortcuts for "Play" and "Stop").
  * Tracks Menu now includes "Mix and Render to New Track".
  * Track Drop-Down Menu now has Move Track To Top and Move Track To Bottom.
  * New right-click menu choice "Delete Label" to remove single labels.
  * "Snap To" now offers choice of snap to the "closest" or "prior" position.
    Note: the previous "Snap To On" keyboard shortcut will no longer work.
  * "Snap To" settings are now independent for each project.
  * Effects:
  * Truncate Silence: redesigned with simpler option "Truncate Detected
    Silence" to shorten to the specified length without compressing silence.
  * VST effects: New "Settings" dialog lets you specify buffer size (for
    faster processing) and enable buffer delay compensation (to prevent
    inserted silence). Compensation may cause a crash in a few plug-ins.
  * VST effects now support standard FXP presets.
  * LV2 effects are now supported on all platforms (textual interface only).
  * Import or export using FFmpeg now requires FFmpeg 1.2 or later (or libav
    0.8 or later). For recommended downloads of recent FFmpeg please visit:
    http://manual.audacityteam.org/o/man/faq_installation_and_plug_ins.html#ffdown .
  * New Tamil translation (largely complete).
  * (Windows) FLAC exports can now exceed 2 GB in size.
  * (OS X) Easier Audacity installation using the DMG: drag the Audacity folder
    to the /Applications shortcut,
  * (OS X) Audacity 2.0.6 will not officially support OS X 10.10 Yosemite when
    released (in particular, Apple Audio Units may not open in Audacity).
  * (Linux) Self-compiled builds of Audacity now search for system LADSPA
    effects in /usr/lib/ladspa.
  - Added patch audacity-flac_assert.h.patch to build against flac 1.3.0.
* Sat Feb 22 2014 dap.darkness@gmail.com
- Update to 2.0.5:
  * Audacity 2.0.4 to hang or the computer to crash. WDM-KS has
    been removed from Audacity 2.0.5 while we work on safely
    enabling this host.
  * You can now navigate through an effect or other dialog using
    keyboard TAB.
  * See more at
    http://wiki.audacityteam.org/wiki/Release_Notes_2.0.5
* Tue Sep 10 2013 fisiu@opensuse.org
- Update to 2.0.4:
  * New "Reverb" effect to replace GVerb, based on the original "Freeverb".
  * New View > Go to Selection Start and Go to Selection End commands.
  * New Tracks > Align End to End command to append existing tracks to each other.
  * Change Tempo now supports fractional BPM.
  * Plot Spectrum now supports FFT sizes up to 65536.
  * WAV files now support "Album Title", "Track Number" and "Genre"
    LIST INFO tags and also support ID3 tags.
  * Handle a bug in older iPods or some OS X applications that cause them
    to refuse AIFF files whose metadata contains an uneven number of characters,
  * CTRL + ALT can now be used to smooth samples in Draw Tool.
  * Modules Preferences replaced with a dialog on launch of Audacity enabling
    you to choose which modules to load.
  * Many bug fixes.
* Fri Mar 29 2013 kkaempf@suse.com
- Update to version 2.0.3
  Bug fixes
  * General
  - Crash using Undo whilst time-shifting a track.
  - Crash using Repair if the selection extended into an empty track.
  - Export Multiple didn't prevent export if there was no audio or all
    audio was muted. This allowed export of small invalid files.
  * Time Track
  - Loop Play of a speeded-up track inserted silence.
  - Playback and rendering was significantly inaccurate, creating audible
    and visual glitches.
  * Accessibility
  - The mnemonics character "&" was read out by screen readers in most of
    the Preferences choices.
  - NVDA did not read static text in most dialogs. Text can now be read by
    using INSERT + B.
  - JAWS and Window-eyes misread the "Duration" control in Silence
    Generator.
  - Toolbar buttons could not be pressed by ENTER
  - Other interface bug fixes.
  Changes and Improvements
  * Resampling
  - The SoX Resampler library (libsoxr) has replaced libresample in
    Audacity releases, offering both higher quality and greater speed.
  * Time Tracks new features
  - "Set Range" now changes only the range of the Time Track, preserving
    the pitch/speed set by any existing warp points.
  - Vertical scale added with options for linear and logarithmic display
    and interpolation.
  - Upper and lower speed limits will now be remembered when saving and
    reopening a project in 2.0.3. Warp points in projects saved by
    previous Audacity versions will be correctly restored in 2.0.3.
  - Warp points saved in a 2.0.3 project will be preserved if opened in
    previous versions but playback and display will be incorrect.
  * New effects
  - Studio Fade Out (uses a filtered "S" curve).
  - Adjustable Fade (accessible effect for creating partial fades and
    adjustable fade shapes).
  - Bass and Treble (replaces Bass Boost).
  * General
  - Real sample rates up to 384000 Hz are now supported for playback and
    recording in high resolution devices (the maximum is up to 192000 Hz
    for Windows DirectSound host).
  - Labeled Regions in Edit Menu is renamed to "Labeled Audio" and now
    allows splits to be placed at point labels. Labeled audio regions that
    touch without overlapping are treated as separate regions. Overlapping
    labeled audio regions are treated as a single region.
  - New Croatian translation of Audacity.
  * Compilation
  - CMake is required in order to build libsoxr.
- removed audacity-implicit.patch and audacity-2.0.2-docdir.patch
  both included in 2.0.3
* Mon Oct 22 2012 uli@suse.de
- explicitly disable SSE on non-x86 architectures (fixes ARM,
  probably others)
* Thu Aug 30 2012 reddwarf@opensuse.org
- Update to version 2.0.2
  * A significant bug that caused clicks on split lines has been fixed
  * There are improvements to several toolbars and to some Nyquist effects
- Update to version 2.0.1
  * Keyboard shortcuts can now be allocated to effects
  * Nyquist plug-ins can be added to Chains
- Run spec-cleaner
- Use pkgconfig() style BuildRequires
- Remove conditionals for unsupported openSUSE versions
- Remove taglib build dependency. Not used any more
- Remove libsamplerate dependency. Upstream prefers included libresample
- Remove custom icon. Upstream already has a transparent version.
- Add audacity-2.0.2-docdir.patch patch
- Don't delete MIME type icon. Instead put it in %%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-audacity-project.xpm
- Add %%icon_theme_cache_post, %%mime_database_post and %%desktop_database_post to %%post
- Recommend libmp3lame0, libavformat52, libavcodec52 and libavutil50
* Wed Mar 14 2012 reddwarf@opensuse.org
- Update to version 2.0.0
  * Bug fixes for:
  - Interface:
  - Fixed playback speed and synchronization problems when dragging
    clips or tracks between tracks having different sample rates.
  - Imports and Exports:
  - Fixed crashes when changing the sample format of read-directly WAV
    or AIFF files using the Track Drop-Down Menu.
  - Fixed a crash importing MP3 files that had duplicate metadata tags
    (this is a bug in current libsndfile which has been patched in
    Audacity; MP3 files mislabeled as WAV which have duplicate tags
    will still crash Audacity on Linux if Audacity has been compiled
    against an affected version of system libsndfile).
  - Fixed an issue where excessively high or corrupted sample values in
    the audio could corrupt exports from the start of the problem for
    the rest of the file, and could corrupt the rest of the project.
  - Fixed Audacity could not be compiled against FFmpeg
    0.7.x and 0.8.x.
  - Effects and Analysis:
  - Fixed crash on launch when using "Ambisonic Decoders (PC)" VST
    plug-ins and other plug-ins that enable additional floating point
    exceptions.
  - Fixed Plot Spectrum background could be transparent on some machines.
  - Bug fixes for Click Track, High Pass, Low Pass and Vocal Remover.
  - Chirp, Tone and Silence generators now remember their settings.
  - Other miscellaneous bug fixes.
  * Changes and Improvements:
  - New Interface preference to show the track name in the display (this
    is off by default).
  - Longer default Playback preference for effects preview and preview
    before cut.
  - Restored use of Page Up and Page Down to scroll horizontally.
* Mon Dec 19 2011 detlef@links2linux.de
- Update to version 1.3.14
  * Bug fixes for:
  - Interface:
  - Excessive delay occurred when typing into labels in long projects.
  - Last digit of TimeText controls could not be manipulated in some formats.
  - (Windows, OS X) Play and Record shortcuts did not work after clicking in
    Device Toolbar.
  - (OS X, Linux) Crash occurred if Toolbars were reset during playback or
    recording.
  - Imports and Exports:
  - MP2 files were not importable without FFmpeg library or an import rule.
  - Files that could only be imported using FFmpeg imported as noise with
    no error message if FFmpeg was not available.
  - Files containing PCM audio but an incorrect extension (such as MP3)
    caused a freeze.
  - Effects and Analysis:
  - An empty command could be added to a Chain which then displayed a
    Nyquist error message when run.
  - Plot Spectrum didn't preserve signal level if multiple tracks were
    analyzed.
  - Other bug fixes:
  - Audacity has been provisionally fixed so that it can no longer create
    block files longer than the sample format or project format allows,
    and can no longer delete these, which led to data loss. Any overlong
    blocks found are preserved but "orphaned", so will appear as silence.
  - Orphan block files were wrongly reported if cutting or copying to
    the clipboard then reopening the project in the same session.
  - Fixed some crashes and incorrect movement of audio when dragging tracks.
  - (Windows) Data loss is now prevented when encountering a corrupted
    .aup file created in ANSI builds.
  - (Linux) Restore building if USE_PORTMIXER is not defined.
  * Changes and Improvements:
  - Normalize: Faster processing and improved interface. Left-right balance
    in unsplit stereo tracks is now preserved by default, with a checkbox
    option provided to process stereo channels independently.
  - Spectrograms now allow window sizes up to 32768 and frequencies up to
    half the sample rate (the maximum possible).
  - Mix and Render now preserves clip length by not rendering white space
    between time zero and first audio, and preserves audio before time zero.
    To retain silence before the audio starts, generate silence after render.
  - Grouped some Edit Menu items into "Remove Audio" and "Clip Boundaries".
  - CleanSpeech Mode removed from Interface Preferences (it still runs if it
    was enabled in a previous Audacity but can only be turned off there).
  - (OS X) Added support for AudioUnit MusicEffects (but no MIDI support).
  - (Linux) Set the per-user files directory per the program name set in
    configure.
  - (Linux) Changed the default location of the Audacity temporary directory
    to be in /var/tmp not /tmp, so preserving the directory between reboots.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Sep  7 2011 mseben@gmail.com
- added audacity-1.3.13-div_by_zero_fix.patch to fix audacity crash
  while opening invalid wav file (bnc#711737)
* Fri Aug 19 2011 reddwarf@opensuse.org
- Update Source tag for the new _service file-less Factory policy
- Add audacity-1.3.13-ffmpeg.patch to compile with latest ffmpeg
* Sun Apr 17 2011 detlef@links2linux.de
- Update to version 1.3.13
  * Numerous bug fixes
  - Crashes on Windows when clicking in the track or in effects dialogs.
  - Crashes on OS X when closing or quitting.
  - Warning (on by default) now provided when importing uncompressed audio
    files and when read-directly uncompressed files are missing.
  - Full support added for later versions of the optional FFmpeg library up
    to current FFmpeg HEAD. More compatible U-Law/A-Law exports.
  - VST effects processing restored to full speed. Hang fixed when launching
    on OS X 10.5 PPC with VST effects present.
  - (OS X) Files imported from iTunes could create invalid characters in the
    .aup project file. See here for help re-opening older projects that have
    this error.
  - (Linux) Crashes or stalled recordings using the pulse device. Crashes
    using Play-at-Speed if Audacity was configured with libsamplerate.
  * Changes and Improvements
  - Control Toolbar renamed to Transport Toolbar. Input/output selection
    moved from Mixer Toolbar to improved Device Toolbar (on by default).
  - New "Sync-Lock Tracks" feature (turned on in the Tracks menu).
  - Equalization now supports importing and exporting curves. Noise Removal
    improvements including new option to isolate noise.
  - Improved Automatic Crash Recovery with all project changes autosaved.
  - New "Extended Import" Preferences for specifying audio file importers.
  - (Windows and Linux) Close button now quits on closing the last window
    while File > Close clears to a new, empty project.
* Tue Dec 28 2010 sbrabec@suse.cz
- Compile with wxWidgets-wxcontainer, it does not compile with STL
  variant.
* Mon Oct  4 2010 reddwarf@opensuse.org
- Cleaned with spec-cleaner
- Fix support for newer ffmpeg versions
- Use download/verify services
- Add -implicit patch as suggested by post-build scripts
* Fri Jun  4 2010 mseben@novell.com
- add LICENSE_NYQUIST.txt to clarify licensing of libnyquist source
  files
* Wed May 26 2010 cmorve69@yahoo.es
- Fix build-compare
- Fix ffmpeg support
* Sat Apr 17 2010 cmorve69@yahoo.es
- Updated no_buildstamp patch.
* Tue Apr 13 2010 davejplater@gmail.com
- Update to version 1.3.12
- Bug fixes for:
  * Imports and Exports:
  * AAC files could not be exported at 48000 Hz
  * When importing multiple native file formats using FFmpeg, all
    files after the first reverted to using the native importer
  * FFmpeg custom export window too large on 800 x 600 resolution
    monitors
  * Projects froze if files imported via On-Demand were no longer
    available
  * (Linux) WAV/AIFF exports were corrupted if overwriting an aliased
    file which had been imported using the command line
  * Labels:
  * Cutting or deleting a region in the waveform and label track did
    not move the labels in advance of the cut
  * Incorrect behavior snapping to labels and boundaries when Snep To
    was enabled
  * Labels can now be reversed if included with the audio selection
  * Other bug fixes:
  * When using non-English languages, Generate effects truncated the
    selected region
  * Mice with high-precision scroll-wheels could cause a crash
  * Changing recording preferences using the Transport menu did
    not update the menu in other open projects
  * (Windows 7) Clicking in a file open or save dialog caused files or
    folders to disappear from the list, and file filtering was broken
- Changes and improvements:
  * A hover tooltip is now provided if the Mixer Toolbar input selector
    cannot control the system slider for the selected input.
  * More intuitive behavior when moving and resizing labels by dragging
  * Support added for importing lists of files (LOF) containing relative
    paths
  * Export Multiple: new option to use a numerical prefix before existing
    label or track names; "Success" dialog now resizable
  * New Equalization preset "Inverse RIAA", with new button to invert
    other curves
  * Timer Record now remembers last scheduled duration
  * Meter Toolbar can now be made much narrower, and so more suitable for
    vertical orientation
  * New Preferences choice for "System" language which is used on first
    run instead of asking user to choose language
  * Warning now provided if WAV/AIFF exports are not successfully
    completed
  * (Linux) Improved icon set in compliance with freedesktop.org
    Icon Theme Specification 0.6
* Mon Mar 15 2010 coolo@novell.com
- rework previous fix without autoreconf in patching configure
  directly
* Mon Mar 15 2010 dimstar@opensuse.org
- Add audacity-nomac.patch: remove the mac checks from configure.
  The check is actually build a test program which fails due to
  missing headers. As consequence: start autoreconf in
  lib-src/portmixer.
* Mon Jan 25 2010 mseben@novell.com
- updated to 1.3.11
  - Bug fixes for:
  * Too much audio exported when exporting partial selections
  * Exports via FFmpeg corrupted if included metadata; M4A now supports metadata export
  * Nyquist plug-ins did not add labels to an existing label track
  * Crash opening Preferences when no audio devices available
  * Timer Record and Sound Activated Recording bugs
  * (Windows) Installer now installs correctly over previous Audacity versions
  * Miscellaneous crashes and interface issues
  - Improvements:
  * (Windows) Higher resolution icon file
  * New Sound Finder plug-in for labelling regions of audio
* Fri Jan  8 2010 vuntz@opensuse.org
- Remove unneeded glib-devel BuildRequires.
* Sun Dec 13 2009 cmorve69@yahoo.es
- Remove buildstamp to help build-compare
* Tue Dec  8 2009 mseben@novell.com
- Update to 1.3.10
  - Bug fixes
  * Freeze importing audio files when Default View Mode set to Pitch (EAC)
  * Simultaneous On-Demand imports sorted incorrectly
  * WAV or AIFF files imported as noise if Preferences set to copy in the data at 24-bit quality
  * WMA exports corrupted if they contained metadata
  * Metadata Editor appeared before the Export window when exporting to any format
  * Crash or hang using Equalization on longer tracks
  * Reverse did not reverse clip boundaries
  * Nyquist - Excessive memory consumption led to slow processing or crashes
  * Nyquist - Values appearing in text boxes not always the default or previously entered values
  * Nyquist - Errors running in European locales where comma used as decimal separator
  * VST effects remained in Effect menu even when re-scanned and no longer available
  * Truncate Silence produced incorrect results if silences spanned a block boundary
  * Spurious "not writable/disk full" errors when saving projects
  * Playing, rendering or exporting multiple tracks led to desynchronized playback or loss of audio data
  * Crash opening Preferences when no recording and/or playback devices enabled or connected
  * Preferences window: OK button did not respond to ENTER when a tab selected in left-hand panel
  * Mixer Board solo button handling
  * (Windows) After a period launching correctly, Audacity sometimes did not come up on top at launch
  * (Mac OS X) Correctly installed Help folder could not be found
  * (Mac OS X and Linux) Output slider could affect VU playback meter which then did not reflect actual waveform volume level
  * (Linux) Undoing or redoing a label edit could cause a crash
  - Changes and improvements:
  * Linked audio and label tracks disabled until a future Beta version so they can be bug fixed
  * Input volume slider will be disabled if it doesn't have proper control of system slider; use the system slider instead
  * Proper support for copying/pasting label-with-audio including label text; new Edit > Paste Text to New Label menu item to paste system clipboard
  * Contrast Tool now modeless, more intuitive handling of multiple project windows, various other minor improvements
- obsolete gsocket-conflict.patch
* Thu Nov  5 2009 davejplater@gmail.com
- Update to 1.3.9 adapted patches and remade audacity-1.3.9-audiodevdefaults.patch
  * Crash, slow launch or excessive CPU/memory use arising from automatic VST support:
    o VST instrument plug-ins should now be correctly ignored
    o VST effects now scanned only at start of first session that detects them, then cached
    o Effects are now not loaded or opened until needed
    o New "Effects" tab in Preferences to enable/disable VST effects and enable VST rescan on next launch
  * Default View Mode now works
  * Chains now always apply their stored parameters rather than those last used in Effect menu
  * Non-MP3 files imported via drag or Recent Files caused crash if filter in file open window set to MP3
  * AAC exports (using the optional FFmpeg library) silenced
  * Generating audio always fitted the project in the window; fit now done only if generating in new track
  * View menu items/shortcuts incorrectly disabled when playing or recording
  * DTMF generator defaulted to zero duration on open
  * Unwanted interactions between linked audio and label tracks
  * Various other interface bugs
  * Compressor: new option to compress based on peaks, improved attack and decay time support
  * Mixer Board: improved design, more responsive meters and now interacts fully with Track Panel in main window
* Fri Jul 31 2009 mseben@suse.cz
-  added vamp-plugin-sdk-devel to buildrequires (for 11.2 and higher)
* Thu Jul 23 2009 mseben@suse.cz
- update to 1.3.8 see full changelog : http://audacity.sourceforge.net/download/features-1.3-a
  Effects and Analysis:
  * VST Effects now display GUI by default
  * Faster Equalization and Noise Removal;
  * Chains applied to files now clear temporary data after processing each file
  * Updated Nyquist implementation with support for SAL syntax and improved memory management
  * Plot Spectrum now analyzes up to 237.8 seconds of audio, with separate windows
  for each project and improved display; new preferences for Spectrograms
  * Contrast Analysis tool now modeless for easier use
  Interface:
  * Draft Manual/Quick Help included in Windows and Mac installers
  * New "Mixer Board" view with per-track VU meters
  * Mute, solo, gain, pan and track height saved in projects
  * More compact Preferences window with easier-to-use Keyboard tab and new toolbars shortcuts
  * New Screenshot Tools and improved screen reader support
  Other:
  * Record more than 16 channels (hardware/drivers permitting)
  * Improved support for non-mmap ALSA devices such as PulseAudio
  * 32-bit float data over 0 dB now handled without clipping
  * "Stop" option when importing preserves already imported data
  * AMR NB export now supported if the optional FFmpeg library is installed
  * Faster waveform drawing and better response in multi-track projects
- obsolete : return_non_void.patch,endian-fix.patch,font-fix.patch,
    strict-aliasing.patch,wxGTK_with_stl.patch,modal-help-dialog.patch,
    desktop_file.patch,portaudio-non-mmap-alsa.patch,startup_fix.patch
- added gsocket-conflict.patch to fix GSocket conflict
- added taglib-devel to BR
* Fri May 29 2009 mseben@suse.cz
- fix startup crash (startup_fix.patch)
* Thu May 21 2009 cmorve69@yahoo.es
- Got portaudio-non-mmap-alsa.patch and audiodevdefaults.patch from
  Fedora to allow it to work with PulseAudio
* Tue May 19 2009 cmorve69@yahoo.es
- Add alsa-devel BR to allow ALSA output
* Mon May 11 2009 cmorve69@yahoo.es
- removed unneeded BuildRequires
- make ffmpeg, mad and twolame support build options
- use upstream .desktop file
- do not force -fno-strict-aliasing since upstream already does
* Wed Apr  8 2009 mseben@suse.cz
- added wxGTK_with_stl.patch to fix build issues when linking wxGTK
  configured with --enable-stl flag
* Mon Feb 23 2009 mseben@suse.cz
- added return_non_void.patch to fix non-void return value (bnc#477654)
* Mon Feb  2 2009 mseben@suse.cz
- updated to version 1.3.7
  Bug Fixes:
  * Muting/soloing caused incorrect channel results in exported
  stereo files
  * Nyquist effects: pasted unmodified audio into the result,
  no progress bar, truncation of processed audio on cancel
  * Noise Removal: pasted unmodified audio into the result, unwanted
  filtering tail
  * Uncompressed exports: export as WAV could be corrupted if
  overwriting to same file, export multiple to uncompressed formats
  only produced 16-bit WAV
  * Compressed exports: MP3 exports now produce correct bit rate
  mode, quality and length, with improved metadata visibility
  in player applications, WMA exports containing metadata are now correct
  * Restored support for multi-channel recording devices that can
  record more than two channels using Audacity
  * fixes for spurious clipping, label typing, no shortcuts after
  running effects
  * project rate now always changes to respect that of first imported file
  New Features:
  * F11 Full Screen mode, high-quality "Sliding Time Scale/Pitch Shift"
  effect, Audio Contrast Analyzer
  Other changes:
  * As a first step towards improving latency correction, a fixed
  rather than variable correction is now applied
  * Numerous minor interface fixes and improvements
- obsolete *-compile.patch, *-locale.patch
* Mon Jan 12 2009 mseben@suse.cz
- fixed Khmer translation file (*-locale.patch)
- added array-delete.patch to fix array delete  (bnc#442936)
- added transparent desktop icon (audacity.png)
- obsolete *-portaudio-shlib.patch, *-nosse.patch
* Thu Dec 11 2008 mseben@suse.cz
- updated to version 1.3.6
  Interface:
  * "Save Compressed Copy of Project" saves in much smaller .OGG
    format to facilitate online transmission of projects
  * Improved MIDI import and export routines, and clearer color
    for selection region
  * Default temporary directory on Mac now accessible in Finder
  Import / Export:
  * Stability improvements in on-demand loading
  * FFmpeg: support for latest version of library, improved
    version checks and error messages, stability improvements
    in custom exporter
  Bug Fixes:
  * Crash in "Get Noise Profile" step of Noise Removal at project
    rates below 20480 Hz.
  * Underestimation of peak level in tracks with a small number
    of different peaks
  * Truncate Silence could result in repeated or lost audio if
    applied to the whole of a track
  * Other interface, generating, exporting and platform-specific
    fixes
  Compilation:
  * Added autoconf macro archive to CVS, enabling *.nix users
    without this archive to build --with -MIDI
- renamed *-modal-help-dialog.diff to *-modal-help-dialog.patch,
  also changed for 1.3.6 tarball
- added libexpat-devel to BuildRequires (directory lib-src/expat
  in tarball 1.3.6 no longer exists)
* Thu Nov 20 2008 tiwai@suse.de
- fix modal dialog with the help browser (bnc#440032)
* Wed May 28 2008 anosek@suse.cz
- updated to version 1.3.5
  Recording / Playback
  * Several bugs fixed so that latency correction should be better, and more devices work correctly.
  * Problems with invalid sample rates under Linux should be much rarer.
  * Newer version of Portaudio library.
  * New feature to record onto the end of an existing track (hold Shift while clicking Record).
  Import / Export
  * Updated versions of Libogg, Libvorbis, Libflac, Libsndfile and Twolame libraries.
  * Handling of unsupported file formats more informative.
  * Handling of file names with slashes on OS X improved.
  * New dialog allows replacement of illegal file name characters on all platforms.
  Interface
  * Improved scaling and layout for rulers and VU meters.
  * Envelope fixes/improvements including full control of undo/redo.
  * New keyboard shortcuts and improved menu navigation.
  * Preferences:
    o More intuitive tab arrangement.
    o New options for mute/solo and Metadata Editor behavior.
    o Language can now be changed without restart.
  * Expanded Build Information tab.
  Effects
  * New Vocal Remover plug-in, improvements for Generate effects.
- dropped obsoleted patches (cflags.patch) (CVE-2007-6061.patch)
* Wed May 14 2008 schwab@suse.de
- Remove useless patch.
* Wed Apr  2 2008 anosek@suse.cz
- fixed Insecure symlink handling (bnc#344588) (CVE-2007-6061.patch)
  - temp file is now created in users home directory
* Fri Jan 25 2008 adrian@suse.de
- remove mad-devel in BuildRequires to keep the package as part
  of Factory
* Fri Jan 18 2008 anosek@suse.cz
- updated to version 1.3.4
  New features
    New Welcome Screen with introduction to Audacity.
    New keyboard command: 'Mix and Render to New Track' (bound to Ctrl+Shift+M).
    New keyboard shortcut: "Shift-A" starts playback when stopped, or performs "Stop and Select" when playing.
    Added support for VAMP audio analysis plug-ins.
    Solo button solos only one track at a time, and a track cannot be both mute and solo.
  Interface
    Keyboard shortcuts for making short/long jumps along the timeline.
    Added 'Snap To' in the Selection Bar.
    Made keyboard navigation easier when multiple menu items with the same first letter exist.
    Enhanced interface for label editing.
    Layout of OK/Cancel buttons consistency improved.
    Preferences:
  * "Select all audio in project, if none selected" (on by default).
  * "Beep on completion of longer activities" (system bell, not main output).
  * Other preferences cleaned up and explanations improved.
    Envelopes: Many fixes when copying / pasting / repeating.
    Many translation updates.
    Track height fixed in several cases.
    CleanSpeech mode switching without closing and re-opening fixed.
  Opening/Saving Formats
    Metadata editor added for OGG, FLAC and WAV/AIFF exports, and general improvements.
    Metadata import improved.
    Muted tracks are no longer audible in the exported mix.
  Effects
    Truncate Silence: support for multiple and stereo tracks.
    Dtmf Generator:
  * Added support for keypad letters.
  * Added an amplitude control.
    Compressor: variable decay time added.
    Equalization:
  * Clicks at start / end prevented.
  * Improvements to saved curves being found.
  * Preview works correctly.
    'Merge' command appears in Undo history.
    Clipping detected more reliably.
    Nyquist plug-ins reviewed and enhanced.
    Better (and more) progress bars.
    Cancelling effect always restores previous audio.
    Several improvement to effects in batch mode.
  Recording/Playback
    Improvements to latency correction.
    Updated version of portaudio-v19 library.
  Note that Help is no longer built in, but accessible on the Web via links in Audacity.
- dropped obsoleted patches:
  * flac.patch - already in upstream
  * equalization.patch - already in upstream
  * build.patch
  * hu_update.patch.bz2
- added patch to fix compilation errors (compile.patch)
* Wed Sep 19 2007 prusnak@suse.cz
- fix broken Equalization effect (equalization.patch) [#326217]
* Thu Aug  2 2007 anosek@suse.cz
- fixed Hungarian translation update [#295657] (hu_update.patch)
* Thu Jun 21 2007 sbrabec@suse.cz
- Build with system soundtouch.
- Build with jack support.
* Wed Jun  6 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Tue May 29 2007 prusnak@suse.cz
- updated to 1.3.3
  * added collapse/expand tracks
  * multiple clips per track
  * added selection bar
  * improved label tracks
  * better performance with large projects
  * added transcription toolbar
  * improved accessibility for the visually impaired
  * added auto-save and automatic crash recovery
  * added batch processing
  * metadata may be added to OGG files
  * EQ effect responsiveness improved
  * new Auto Duck effect
  * DTMF tone generator
- dropped obsoleted patches:
  * ambigous.patch
  * overflow-fix.patch (included in update)
  * qualification.patch (included in update)
  * wx-compat.patch
- added patches:
  * flac.patch - adjust for new FLAC 1.1.4 API
  * nosse.patch - don't try to use SSE on non-x86 archs
* Fri Apr 20 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Thu Aug 10 2006 anosek@suse.cz
- fixed build with new version of autotools (audacity-build.patch)
* Sun Feb 19 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Feb 15 2006 sbrabec@suse.cz
- Build with portaudio19 (#151210).
* Mon Jan 30 2006 aj@suse.de
- Further fix to BuildRequires.
* Sun Jan 29 2006 aj@suse.de
- Fix buildrequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 16 2005 sbrabec@suse.cz
- Returned back required wx-compat patch.
* Wed Dec  7 2005 sbrabec@suse.cz
- Updated to version 1.2.4b.
* Wed Nov  9 2005 sbrabec@suse.cz
- Strict aliasing fix.
* Tue Oct 25 2005 sbrabec@suse.cz
- Fixed extra qualification.
- Build with correct CFLAGS.
- Fixed random return values.
* Fri Oct 14 2005 sbrabec@suse.cz
- Disabled mad support.
* Fri Apr 15 2005 mcihar@suse.de
- add SDL-devel-packages because of wxGTK
* Thu Feb 17 2005 hvogel@suse.de
- mark as nosrc
* Tue Nov 23 2004 ro@suse.de
- fix build with current wxGTK
* Mon Nov 22 2004 mcihar@suse.cz
- update to 1.2.3
* Mon Sep  6 2004 mcihar@suse.cz
-fix build on 64-bit arches
* Fri Sep  3 2004 mcihar@suse.cz
- update to 1.2.2
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 1.2.1.
- using wxGTK-compat library.
* Sun Mar 28 2004 tiwai@suse.de
- fixed the segfault at the start up (bug #34313)
- fixed the size of fonts for wxGTK with GTK-2.
- fixed possible buffer overflows.
- build with portaudio-v18, v19 seems problematic.
* Fri Mar  5 2004 tiwai@suse.de
- updated to version 1.2.0 final.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 1.2.0-pre4.
* Thu Jan 22 2004 tiwai@suse.de
- fixed the build with the latest autoconf.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 1.2.0-pre3.
- use portaudio v19 (shared lib).
* Tue Jan 13 2004 tiwai@suse.de
- fixed the neededforbuild for the latest wxGTK with gtk2.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Sun Sep 14 2003 adrian@suse.de
- add AudioVideoEditing Category
* Fri Aug 29 2003 tiwai@suse.de
- fixed the bug of WAVE display.
* Thu Aug 14 2003 tiwai@suse.de
- added desktop file.
* Mon Aug 11 2003 tiwai@suse.de
- updated to version 1.2.0-pre1.
- help file is installed under /usr/share/audacity.
* Thu Jul  3 2003 tiwai@suse.de
- fixed neededforbuild for the recent update of mad.
* Mon May 26 2003 ro@suse.de
- removed unpackaged files from buildroot
* Thu Mar 27 2003 tiwai@suse.de
- updated to version 1.1.3.
  linked with libFLAC and libsamplerate.
* Tue Nov 26 2002 tiwai@suse.de
- updated to version 1.1.1.
- build with the system libsndfile since now audacity supports
  libsndfile 1.0.
- enabled nyquist support.
* Fri Aug 30 2002 tiwai@suse.de
- updated to version 1.1.0 cvs 2002.08.30.
  the 1.1.0 tarball version has a major bug regarding to project
  file management (bug #18662).  this version fixes the problem.
  also, this one includes a help text, which wasn't there.
* Wed Jul 24 2002 tiwai@suse.de
- updated to version 1.1.0.
* Mon Jul  1 2002 tiwai@suse.de
- updated to the stable version 1.0.0-2.
* Wed Apr 17 2002 tiwai@suse.de
- fixed build with gcc-3.1.
* Tue Apr  9 2002 ro@suse.de
- work around autoconf problem: first AC_CHECK_HEADER
  apparently has to be outside of an if ... fi block
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Jan 25 2002 ro@suse.de
- added libpng,libjpeg,libtiff to neededforbuild
* Thu Jan 24 2002 tiwai@suse.de
- initial package version: 0.98.
- built with the shared id3lib.
